import * as interfaces from '../interfaces/index.js';
import { WorkerEvent } from '../classes.workerevent.js';

export const staticResponder: interfaces.TRequestResponser = async (cWorkerEventArg: WorkerEvent) => {
  if (cWorkerEventArg.responderInstruction.type === 'static') {
    const originResponse: any = await fetch(
      `https://statichost.lossless.one/resolve?url=${encodeURI(cWorkerEventArg.request.url)}`
    );

    const cacheHeaders = new Headers();
    for (const kv of originResponse.headers.entries()) {
      cacheHeaders.append(kv[0], kv[1]);
    }
    cacheHeaders.delete('SERVEZONE_ROUTE');
    cacheHeaders.append('SERVEZONE_ROUTE', 'LOSSLESS_EDGE_STATICHOST');
    
    if (cWorkerEventArg.responderInstruction.cacheClientSideForMin) {
      cacheHeaders.delete('Cache-Control');
      cacheHeaders.append('Cache-Control', `public, max-age=${cWorkerEventArg.responderInstruction.cacheClientSideForMin * 60}`);
      cacheHeaders.delete('Expires');
      cacheHeaders.append('Expires', new Date(Date.now() + cWorkerEventArg.responderInstruction.cacheClientSideForMin * 1000).toUTCString());
    }

    const responseForClient = new Response(await originResponse.clone().body, {
      ...originResponse,
      headers: cacheHeaders
    });

    cWorkerEventArg.setResponse(responseForClient);
  }
};
